exceptiontools.ExtraNamedComponentError
=======================================

.. inheritance-diagram:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
